@@ -110,10 +110,9 @@ the second with the current group name.")
 
 (defcustom gnus-group-posting-charset-alist
   '(("^no\\." iso-8859-1)
-    (".*" iso-8859-1)
-    (message-this-is-news iso-8859-1)
     (message-this-is-mail nil)
-    )
+    (".*" iso-8859-1)
+    (message-this-is-news iso-8859-1))
   "Alist of regexps (to match group names) and default charsets to be unencoded when posting."
   :type '(repeat (list (regexp :tag "Group")
 		       (symbol :tag "Charset")))
@@ -853,7 +852,7 @@ If YANK is non-nil, include the original article."
     (save-excursion
       (set-buffer (gnus-get-buffer-create " *gnus environment info*"))
       (gnus-debug))
-    (insert "<#part type=application/emacs-lisp buffer=\" *gnus environment info*\" disposition=inline><#/part>")
+    (insert "<#part type=application/emacs-lisp buffer=\" *gnus environment info*\" disposition=inline description=\"User settings\"><#/part>")
     (goto-char (point-min))
     (search-forward "Subject: " nil t)
     (message "")))
